%global debug_package %{nil}

Name:           hysteria
Version:        2.4.1
Release:        1%{?dist}
Summary:        Hysteria is a powerful, lightning fast and censorship resistant proxy.
License:        MIT
URL:            https://github.com/apernet/hysteria

Source0:        server.yaml
Source1:        client.yaml
Source2:        cert.crt
Source3:        private.key

#BuildRequires:  golang >= 1.20
BuildRequires:  git-core
%{?systemd_requires}
Requires:       tzdata ca-certificates
Provides:       Productivity/Networking/Web/Proxy


%description
Hysteria is a powerful, lightning fast and censorship resistant proxy.


%prep
%setup -q -c -T

%build
# https://pagure.io/go-rpm-macros/c/1cc7f5d9026175bb6cb1b8c889355d0c4fc0e40a
%undefine _auto_set_build_flags
%define TIMESTAMP %(date +"%%F")
export GOPROXY='https://proxy.golang.org,direct'
export GOSUMDB='sum.golang.org'

git clone -b app/v%{version} https://github.com/apernet/hysteria.git >/dev/null 2>&1
cd hysteria
APP_SRC_CMD_PKG="github.com/apernet/hysteria/app/cmd"
COMMIT="$(git rev-parse HEAD)"
SYS_ARCH="$(uname -m)"
if [ "${SYS_ARCH}" = "aarch64" ]; then
    ARCH="arm64"
elif [ "${SYS_ARCH}" = "x86_64" ]; then
    ARCH="amd64"
else
    echo "Not support arch" && exit 1
fi
LDFLAGS="-s -w -X '${APP_SRC_CMD_PKG}.appVersion=v%{version}' -X '${APP_SRC_CMD_PKG}.appCommit=${COMMIT}' -X '${APP_SRC_CMD_PKG}.appDate=%{TIMESTAMP}' -X '${APP_SRC_CMD_PKG}.appType=release' -X '${APP_SRC_CMD_PKG}.appPlatform=linux' -X '${APP_SRC_CMD_PKG}.appArch=${ARCH}' -buildid="
env CGO_ENABLED=0 go build -v -trimpath -ldflags "$LDFLAGS" -o %{name} ./app


%install
%{__install} -d %{buildroot}%{_bindir}
%{__install} -p -m 755 hysteria/%{name} %{buildroot}%{_bindir}

%{__install} -d %{buildroot}%{_sysconfdir}/%{name}
%{__install} -p -m 644 %{S:0} %{buildroot}%{_sysconfdir}/%{name}/server.yaml
%{__install} -p -m 644 %{S:1} %{buildroot}%{_sysconfdir}/%{name}/client.yaml
%{__install} -p -m 644 %{S:2} %{buildroot}%{_sysconfdir}/%{name}/cert.crt
%{__install} -p -m 644 %{S:3} %{buildroot}%{_sysconfdir}/%{name}/private.key

%{__install} -d %{buildroot}%{_unitdir}
cat > %{buildroot}%{_unitdir}/%{name}-server.service <<EOF
[Unit]
Description=Hysteria server service
Documentation=https://github.com/apernet/hysteria
After=network.target nss-lookup.target

[Service]
CapabilityBoundingSet=CAP_NET_ADMIN CAP_NET_BIND_SERVICE
AmbientCapabilities=CAP_NET_ADMIN CAP_NET_BIND_SERVICE
NoNewPrivileges=true
ExecStart=/usr/bin/hysteria server -c /etc/hysteria/server.yaml
Restart=on-failure
LimitNPROC=10000
LimitNOFILE=1000000

[Install]
WantedBy=multi-user.target
EOF
cat > %{buildroot}%{_unitdir}/%{name}-client.service <<EOF
[Unit]
Description=Hysteria client service
Documentation=https://github.com/apernet/hysteria
After=network.target nss-lookup.target

[Service]
CapabilityBoundingSet=CAP_NET_ADMIN CAP_NET_BIND_SERVICE
AmbientCapabilities=CAP_NET_ADMIN CAP_NET_BIND_SERVICE
NoNewPrivileges=true
ExecStart=/usr/bin/hysteria client -c /etc/hysteria/client.yaml
Restart=on-failure
LimitNPROC=10000
LimitNOFILE=1000000

[Install]
WantedBy=multi-user.target
EOF
cat > %{buildroot}%{_unitdir}/%{name}-server@.service <<EOF
[Unit]
Description=Hysteria server service
Documentation=https://github.com/apernet/hysteria
After=network.target nss-lookup.target

[Service]
CapabilityBoundingSet=CAP_NET_ADMIN CAP_NET_BIND_SERVICE
AmbientCapabilities=CAP_NET_ADMIN CAP_NET_BIND_SERVICE
NoNewPrivileges=true
ExecStart=/usr/bin/hysteria server -c /etc/hysteria/%i.yaml
Restart=on-failure
LimitNPROC=10000
LimitNOFILE=1000000

[Install]
WantedBy=multi-user.target
EOF
cat > %{buildroot}%{_unitdir}/%{name}-client@.service <<EOF
[Unit]
Description=Hysteria client service
Documentation=https://github.com/apernet/hysteria
After=network.target nss-lookup.target

[Service]
CapabilityBoundingSet=CAP_NET_ADMIN CAP_NET_BIND_SERVICE
AmbientCapabilities=CAP_NET_ADMIN CAP_NET_BIND_SERVICE
NoNewPrivileges=true
ExecStart=/usr/bin/hysteria client -c /etc/hysteria/%i.yaml
Restart=on-failure
LimitNPROC=10000
LimitNOFILE=1000000

[Install]
WantedBy=multi-user.target
EOF

# shell completions
install -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions
./hysteria/%{name} completion bash > %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -d -m 0755 %{buildroot}%{_datadir}/zsh/site-functions
./hysteria/%{name} completion zsh > %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -d -m 0755 %{buildroot}%{_datadir}/fish/vendor_completions.d
./hysteria/%{name} completion fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish


%post
%systemd_post %{name}-server.service
%systemd_post %{name}-client.service

%preun
%systemd_preun %{name}-server.service
%systemd_preun %{name}-client.service

%postun
%systemd_postun_with_restart %{name}-server.service
%systemd_postun_with_restart %{name}-client.service

%files
%{_bindir}/%{name}
%{_unitdir}/%{name}-server.service
%{_unitdir}/%{name}-client.service
%{_unitdir}/%{name}-server@.service
%{_unitdir}/%{name}-client@.service
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/server.yaml
%config(noreplace) %{_sysconfdir}/%{name}/client.yaml
%config(noreplace) %{_sysconfdir}/%{name}/cert.crt
%config(noreplace) %{_sysconfdir}/%{name}/private.key
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/zsh/site-functions/_%{name}
%{_datadir}/fish/vendor_completions.d/%{name}.fish
%license hysteria/LICENSE.md
%doc hysteria/README.md

%changelog
* Sat Apr 13 2024 Teddysun <i@teddysun.com> - 2.4.1-1
- Update to version 2.4.1

* Sun Mar 24 2024 Teddysun <i@teddysun.com> - 2.4.0-1
- Update to version 2.4.0

* Sun Mar 10 2024 Teddysun <i@teddysun.com> - 2.3.0-1
- Update to version 2.3.0

* Sat Jan 27 2024 Teddysun <i@teddysun.com> - 2.2.4-1
- Update to version 2.2.4

* Sat Dec 30 2023 Teddysun <i@teddysun.com> - 2.2.3-1
- Update to version 2.2.3

* Thu Nov 23 2023 Teddysun <i@teddysun.com> - 2.2.2-1
- Update to version 2.2.2

* Sun Nov 19 2023 Teddysun <i@teddysun.com> - 2.2.1-1
- Update to version 2.2.1

* Fri Oct 20 2023 Teddysun <i@teddysun.com> - 2.1.1-1
- Update to version 2.1.1

* Wed Oct 18 2023 Teddysun <i@teddysun.com> - 2.1.0-1
- Update to version 2.1.0
